.. include:: /_includes/wip_prolog.rst

:mod:`stix.threat_actor` Module
==================================

.. module:: stix.threat_actor

Classes
-------

.. autoclass:: ThreatActor
	:show-inheritance:
	:members:

.. autoclass:: AssociatedActors
	:show-inheritance:
	:members:

.. autoclass:: AssociatedCampaigns
	:show-inheritance:
	:members:

.. autoclass:: ObservedTTPs
	:show-inheritance:
	:members:
